==> mule-artifact-ast-xml-parser-1.4.10-20251105.195104-8-sources.jar: org/mule/runtime/ast/internal/xml/resolver/CachingExtensionSchemaGenerator.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.ast.internal.xml.resolver;

import static org.mule.runtime.ast.internal.dsl.DslConstants.THIS_NAMESPACE;

import org.mule.runtime.api.dsl.DslResolvingContext;
import org.mule.runtime.api.meta.model.ExtensionModel;
import org.mule.runtime.extension.api.dsl.syntax.resources.spi.ExtensionSchemaGenerator;

import com.github.benmanes.caffeine.cache.Cache;
import com.github.benmanes.caffeine.cache.Caffeine;

/**
 * Decorator for {@link ExtensionSchemaGenerator} that caches the values returned by the
 * {@link #generate(ExtensionModel, DslResolvingContext)} method, using the {@link ExtensionModel} as key.
 *
 * @since 1.0
 */
public class CachingExtensionSchemaGenerator implements ExtensionSchemaGenerator {

  private final ExtensionSchemaGenerator delegate;
  private final Cache<ExtensionModel, String> schemasCache;

  public CachingExtensionSchemaGenerator(ExtensionSchemaGenerator delegate) {
    this.delegate = delegate;
    this.schemasCache = Caffeine.newBuilder().build();
  }

  @Override
  public String generate(ExtensionModel extensionModel, DslResolvingContext context) {
    // do not cache the application extension model as there's no point in reusing it
    if (THIS_NAMESPACE.equals(extensionModel.getXmlDslModel().getNamespace())) {
      return delegate.generate(extensionModel, context);
    }

    return schemasCache.get(extensionModel, em -> delegate.generate(em, context));
  }

}

==> mule-artifact-ast-xml-parser-1.6.1-20251001.153903-7-sources.jar: org/mule/runtime/ast/internal/xml/resolver/CachingExtensionSchemaGenerator.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.ast.internal.xml.resolver;

import static org.mule.runtime.ast.internal.dsl.DslConstants.THIS_NAMESPACE;

import org.mule.runtime.api.dsl.DslResolvingContext;
import org.mule.runtime.api.meta.model.ExtensionModel;
import org.mule.runtime.extension.api.dsl.syntax.resolver.DslSyntaxResolver;
import org.mule.runtime.extension.api.dsl.syntax.resources.spi.ExtensionSchemaGenerator;

import com.github.benmanes.caffeine.cache.Cache;
import com.github.benmanes.caffeine.cache.Caffeine;

/**
 * Decorator for {@link ExtensionSchemaGenerator} that caches the values returned by the
 * {@link #generate(ExtensionModel, DslResolvingContext)} method, using the {@link ExtensionModel} as key.
 *
 * @since 1.0
 */
public class CachingExtensionSchemaGenerator implements ExtensionSchemaGenerator {

  private final ExtensionSchemaGenerator delegate;
  private final Cache<ExtensionModel, String> schemasCache;

  public CachingExtensionSchemaGenerator(ExtensionSchemaGenerator delegate) {
    this.delegate = delegate;
    this.schemasCache = Caffeine.newBuilder().build();
  }

  @Override
  public String generate(ExtensionModel extensionModel, DslResolvingContext context) {
    // do not cache the application extension model as there's no point in reusing it
    if (THIS_NAMESPACE.equals(extensionModel.getXmlDslModel().getNamespace())) {
      return delegate.generate(extensionModel, context);
    }

    return schemasCache.get(extensionModel, em -> delegate.generate(em, context));
  }

  @Override
  public String generate(ExtensionModel extensionModel, DslResolvingContext context, DslSyntaxResolver dsl) {
    // do not cache the application extension model as there's no point in reusing it
    if (THIS_NAMESPACE.equals(extensionModel.getXmlDslModel().getNamespace())) {
      return delegate.generate(extensionModel, context, dsl);
    }

    return schemasCache.get(extensionModel, em -> delegate.generate(em, context, dsl));
  }
}
